@@ -90,6 +90,7 @@ new ApiGatewayToLambda(this, "ApiGatewayToLambdaPattern", new ApiGatewayToLambda
 |existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |apiGatewayProps?|[`api.LambdaRestApiProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.LambdaRestApi.html)|Optional user-provided props to override the default props for the API.|
+|createUsagePlan?|boolean|Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true. @default - true (to match legacy behavior)|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
@@ -185,6 +186,7 @@ class ApiGatewayToLambda(
         id: builtins.str,
         *,
         api_gateway_props: typing.Any = None,
+        create_usage_plan: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -193,6 +195,7 @@ class ApiGatewayToLambda(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
+        :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -207,6 +210,7 @@ class ApiGatewayToLambda(
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToLambdaProps(
             api_gateway_props=api_gateway_props,
+            create_usage_plan=create_usage_plan,
             existing_lambda_obj=existing_lambda_obj,
             lambda_function_props=lambda_function_props,
             log_group_props=log_group_props,
@@ -242,6 +246,7 @@ class ApiGatewayToLambda(
     jsii_struct_bases=[],
     name_mapping={
         "api_gateway_props": "apiGatewayProps",
+        "create_usage_plan": "createUsagePlan",
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
         "log_group_props": "logGroupProps",
@@ -252,6 +257,7 @@ class ApiGatewayToLambdaProps:
         self,
         *,
         api_gateway_props: typing.Any = None,
+        create_usage_plan: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -259,6 +265,7 @@ class ApiGatewayToLambdaProps:
         '''The properties for the ApiGatewayToLambda class.
 
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
+        :param create_usage_plan: Whether to create a Usage Plan attached to the API. Must be true if apiGatewayProps.defaultMethodOptions.apiKeyRequired is true Default: - true (to match legacy behavior)
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
@@ -270,12 +277,15 @@ class ApiGatewayToLambdaProps:
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__9be9eacf3e580c106bf97e65962dc01354d2e8ce46fb5733931b1f0ec7f5a9ef)
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument create_usage_plan", value=create_usage_plan, expected_type=type_hints["create_usage_plan"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
+        if create_usage_plan is not None:
+            self._values["create_usage_plan"] = create_usage_plan
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if lambda_function_props is not None:
@@ -292,6 +302,18 @@ class ApiGatewayToLambdaProps:
         result = self._values.get("api_gateway_props")
         return typing.cast(typing.Any, result)
 
+    @builtins.property
+    def create_usage_plan(self) -> typing.Optional[builtins.bool]:
+        '''Whether to create a Usage Plan attached to the API.
+
+        Must be true if
+        apiGatewayProps.defaultMethodOptions.apiKeyRequired is true
+
+        :default: - true (to match legacy behavior)
+        '''
+        result = self._values.get("create_usage_plan")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def existing_lambda_obj(
         self,
@@ -349,6 +371,7 @@ def _typecheckingstub__8cee3d89f313102b389deed0cd200d7ab2323cfe0ad8769e94f7167b7
     id: builtins.str,
     *,
     api_gateway_props: typing.Any = None,
+    create_usage_plan: typing.Optional[builtins.bool] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
     log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
@@ -359,6 +382,7 @@ def _typecheckingstub__8cee3d89f313102b389deed0cd200d7ab2323cfe0ad8769e94f7167b7
 def _typecheckingstub__9be9eacf3e580c106bf97e65962dc01354d2e8ce46fb5733931b1f0ec7f5a9ef(
     *,
     api_gateway_props: typing.Any = None,
+    create_usage_plan: typing.Optional[builtins.bool] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
     log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
